==> ViennaCL-1.7.0.tar.gz: ViennaCL-1.7.0/doc/html/search/all_a.js <==
var searchData=
[
  ['kepler',['kepler',['../namespaceviennacl_1_1ocl.html#ac19deb058c8b979eba1faba219542c35a5e0af0d848ab567eca872f2e0d63c6d1',1,'viennacl::ocl']]],
  ['kernel',['kernel',['../classviennacl_1_1ocl_1_1kernel.html#a13182e83ff95cb6449ab1cabf4fa132c',1,'viennacl::ocl::kernel::kernel()'],['../classviennacl_1_1ocl_1_1kernel.html#a089f54920bc7a176489b59b33597f766',1,'viennacl::ocl::kernel::kernel(cl_kernel kernel_handle, viennacl::ocl::program const &amp;kernel_program, viennacl::ocl::context const &amp;kernel_context, std::string const &amp;name)'],['../classviennacl_1_1ocl_1_1kernel.html#a450baa840c1b940c5c7d279d8b81976b',1,'viennacl::ocl::kernel::kernel(kernel const &amp;other)']]],
  ['kernel',['kernel',['../classviennacl_1_1ocl_1_1kernel.html',1,'viennacl::ocl']]],
  ['kernel_2ehpp',['kernel.hpp',['../kernel_8hpp.html',1,'']]],
  ['kernel_5fgeneration_5fstream',['kernel_generation_stream',['../classviennacl_1_1device__specific_1_1utils_1_1kernel__generation__stream.html',1,'viennacl::device_specific::utils']]],
  ['kernel_5fgeneration_5fstream',['kernel_generation_stream',['../classviennacl_1_1device__specific_1_1utils_1_1kernel__generation__stream.html#a8b2a8f655959816e179090e4c8f52203',1,'viennacl::device_specific::utils::kernel_generation_stream']]],
  ['kernel_5fnot_5ffound',['kernel_not_found',['../classviennacl_1_1ocl_1_1kernel__not__found.html',1,'viennacl::ocl']]],
  ['kernel_5fnot_5ffound',['kernel_not_found',['../classviennacl_1_1ocl_1_1kernel__not__found.html#aa7ee919346ae1f9212c70e73cdffc15d',1,'viennacl::ocl::kernel_not_found']]],
  ['keywords_5f',['keywords_',['../classviennacl_1_1device__specific_1_1mapped__object.html#a9b58112e2f6ebf7e5fcfd5e1aab19208',1,'viennacl::device_specific::mapped_object']]],
  ['kl',['kL',['../structviennacl_1_1device__specific_1_1matrix__product__parameters.html#af26921686a03f05462e889d6dcbe5415',1,'viennacl::device_specific::matrix_product_parameters']]],
  ['krylov_5fdim',['krylov_dim',['../classviennacl_1_1linalg_1_1gmres__tag.html#afec21365bfdf6b200e6387b898b9c899',1,'viennacl::linalg::gmres_tag']]],
  ['krylov_5fsize',['krylov_size',['../classviennacl_1_1linalg_1_1lanczos__tag.html#a4e07073e383c1f5ed160d007f05d6eb3',1,'viennacl::linalg::lanczos_tag::krylov_size(vcl_size_t max)'],['../classviennacl_1_1linalg_1_1lanczos__tag.html#aaad9aa2dc06eb4a5ca272d7fc78fb072',1,'viennacl::linalg::lanczos_tag::krylov_size() const ']]],
  ['ks',['kS',['../structviennacl_1_1device__specific_1_1matrix__product__parameters.html#a52bfcc28584cd62d9619f696954752df',1,'viennacl::device_specific::matrix_product_parameters']]]
];

==> ViennaCL-1.7.1.tar.gz: ViennaCL-1.7.1/doc/html/search/all_a.js <==
var searchData=
[
  ['kepler',['kepler',['../namespaceviennacl_1_1ocl.html#ac19deb058c8b979eba1faba219542c35a5e0af0d848ab567eca872f2e0d63c6d1',1,'viennacl::ocl']]],
  ['kernel',['kernel',['../classviennacl_1_1ocl_1_1kernel.html#a13182e83ff95cb6449ab1cabf4fa132c',1,'viennacl::ocl::kernel::kernel()'],['../classviennacl_1_1ocl_1_1kernel.html#a089f54920bc7a176489b59b33597f766',1,'viennacl::ocl::kernel::kernel(cl_kernel kernel_handle, viennacl::ocl::program const &amp;kernel_program, viennacl::ocl::context const &amp;kernel_context, std::string const &amp;name)'],['../classviennacl_1_1ocl_1_1kernel.html#a450baa840c1b940c5c7d279d8b81976b',1,'viennacl::ocl::kernel::kernel(kernel const &amp;other)']]],
  ['kernel',['kernel',['../classviennacl_1_1ocl_1_1kernel.html',1,'viennacl::ocl']]],
  ['kernel_2ehpp',['kernel.hpp',['../kernel_8hpp.html',1,'']]],
  ['kernel_5ffor_5fmatrix',['kernel_for_matrix',['../namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html#acb933cf08a45fa63d016111dfafa4791',1,'viennacl::linalg::opencl::detail']]],
  ['kernel_5fgeneration_5fstream',['kernel_generation_stream',['../classviennacl_1_1device__specific_1_1utils_1_1kernel__generation__stream.html',1,'viennacl::device_specific::utils']]],
  ['kernel_5fgeneration_5fstream',['kernel_generation_stream',['../classviennacl_1_1device__specific_1_1utils_1_1kernel__generation__stream.html#a8b2a8f655959816e179090e4c8f52203',1,'viennacl::device_specific::utils::kernel_generation_stream']]],
  ['kernel_5fnot_5ffound',['kernel_not_found',['../classviennacl_1_1ocl_1_1kernel__not__found.html#aa7ee919346ae1f9212c70e73cdffc15d',1,'viennacl::ocl::kernel_not_found']]],
  ['kernel_5fnot_5ffound',['kernel_not_found',['../classviennacl_1_1ocl_1_1kernel__not__found.html',1,'viennacl::ocl']]],
  ['keywords_5f',['keywords_',['../classviennacl_1_1device__specific_1_1mapped__object.html#a9b58112e2f6ebf7e5fcfd5e1aab19208',1,'viennacl::device_specific::mapped_object']]],
  ['kl',['kL',['../structviennacl_1_1device__specific_1_1matrix__product__parameters.html#af26921686a03f05462e889d6dcbe5415',1,'viennacl::device_specific::matrix_product_parameters']]],
  ['krylov_5fdim',['krylov_dim',['../classviennacl_1_1linalg_1_1gmres__tag.html#afec21365bfdf6b200e6387b898b9c899',1,'viennacl::linalg::gmres_tag']]],
  ['krylov_5fsize',['krylov_size',['../classviennacl_1_1linalg_1_1lanczos__tag.html#a4e07073e383c1f5ed160d007f05d6eb3',1,'viennacl::linalg::lanczos_tag::krylov_size(vcl_size_t max)'],['../classviennacl_1_1linalg_1_1lanczos__tag.html#aaad9aa2dc06eb4a5ca272d7fc78fb072',1,'viennacl::linalg::lanczos_tag::krylov_size() const ']]],
  ['ks',['kS',['../structviennacl_1_1device__specific_1_1matrix__product__parameters.html#a52bfcc28584cd62d9619f696954752df',1,'viennacl::device_specific::matrix_product_parameters']]]
];
